==> zio-aws-sagemaker_3-5.17.148.1-sources.jar: zio/aws/sagemaker/model/ListImagesResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.sagemaker.model.primitives.NextToken
import scala.jdk.CollectionConverters.*
final case class ListImagesResponse(
    images: Option[Iterable[zio.aws.sagemaker.model.Image]] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ListImagesResponse = {
    import ListImagesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ListImagesResponse
      .builder()
      .optionallyWith(
        images.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.images)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.ListImagesResponse.ReadOnly =
    zio.aws.sagemaker.model.ListImagesResponse.wrap(buildAwsValue())
}
object ListImagesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ListImagesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ListImagesResponse =
      zio.aws.sagemaker.model.ListImagesResponse(
        images.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def images: Option[List[zio.aws.sagemaker.model.Image.ReadOnly]]
    def nextToken: Option[NextToken]
    def getImages
        : ZIO[Any, AwsError, List[zio.aws.sagemaker.model.Image.ReadOnly]] =
      AwsError.unwrapOptionField("images", images)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ListImagesResponse
  ) extends zio.aws.sagemaker.model.ListImagesResponse.ReadOnly {
    override val images: Option[List[zio.aws.sagemaker.model.Image.ReadOnly]] =
      scala
        .Option(impl.images())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.Image.wrap(item)
          }.toList
        )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.sagemaker.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ListImagesResponse
  ): zio.aws.sagemaker.model.ListImagesResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sagemaker_3-6.20.74.2-sources.jar: zio/aws/sagemaker/model/ListImagesResponse.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.NextToken
import scala.jdk.CollectionConverters.*
final case class ListImagesResponse(
    images: Optional[Iterable[zio.aws.sagemaker.model.Image]] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.ListImagesResponse = {
    import ListImagesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.ListImagesResponse
      .builder()
      .optionallyWith(
        images.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.images)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.ListImagesResponse.ReadOnly =
    zio.aws.sagemaker.model.ListImagesResponse.wrap(buildAwsValue())
}
object ListImagesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.ListImagesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.ListImagesResponse =
      zio.aws.sagemaker.model.ListImagesResponse(
        images.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def images: Optional[List[zio.aws.sagemaker.model.Image.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getImages
        : ZIO[Any, AwsError, List[zio.aws.sagemaker.model.Image.ReadOnly]] =
      AwsError.unwrapOptionField("images", images)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.ListImagesResponse
  ) extends zio.aws.sagemaker.model.ListImagesResponse.ReadOnly {
    override val images
        : Optional[List[zio.aws.sagemaker.model.Image.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.images())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.sagemaker.model.Image.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.sagemaker.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.ListImagesResponse
  ): zio.aws.sagemaker.model.ListImagesResponse.ReadOnly = new Wrapper(impl)
}
